require "birdseed/version"
require 'json'
require 'rest-client'
require 'hashie'

module Birdseed
  REQUEST_TIMEOUT = 60
  OPEN_TIMEOUT = 5
  @@api_key = "SET_YOUR_API_KEY"
  @@fatbird_host = nil # Optional

  def self.api_key=(key)
    @@api_key = key
  end

  def self.fatbird_host=(host)
    @@fatbird_host = host
  end

  def self.fatbird_host
    @@fatbird_host ||= "https://fatbird.edmodo.com"
  end

  # See https://github.com/edmodo/fatbird#send-emails-using-rest-api
  def self.deliver(options={})
    api_key = options.delete(:api_key) || @@api_key

    response = RestClient::Request.execute(
      method: :post,
      url: "#{self.fatbird_host}/deliveries",
      payload: JSON.generate(options),
      headers: {"Authorization" => "api_key #{api_key}", :content_type => :json, :accept => :json},
      timeout: REQUEST_TIMEOUT,
      open_timeout: OPEN_TIMEOUT
    )
    Hashie::Mash.new(JSON.parse(response))
  end

  # See https://github.com/edmodo/fatbird#send-emails-using-rest-api
  def self.deliver_item(options={})
    api_key = options.delete(:api_key) || @@api_key

    response = RestClient::Request.execute(
      method: :post,
      url: "#{self.fatbird_host}/delivery_items",
      payload: JSON.generate(options),
      headers: {"Authorization" => "api_key #{api_key}", :content_type => :json, :accept => :json},
      timeout: REQUEST_TIMEOUT,
      open_timeout: OPEN_TIMEOUT
    )
    Hashie::Mash.new(JSON.parse(response))
  end

  def self.sample_data(campaign_id, options={})
    api_key = options.delete(:api_key) || @@api_key
    default_value = options[:default_value] || 'VALUE'
    response = RestClient.get(
      "#{self.fatbird_host}/campaigns/#{campaign_id}/sample_data?dafault_value=#{default_value}",
      {"Authorization" => "api_key #{api_key}", :content_type => :json, :accept => :json}
    )
    JSON.parse(response)
  end

end
